@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,7 +26,7 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
  * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
@@ -68,11 +68,11 @@ public class TimeZoneNames_sa extends TimeZoneNamesBundle {
     protected final Object[][] getContents() {
         final String[] GMT = new String[] {
                "\u0917\u094d\u0930\u0940\u0928\u0935\u093f\u091a \u092e\u0940\u0928 \u0938\u092e\u092f\u0903",
+               "GMT",
                "",
+               "BST",
                "",
-               "",
-               "",
-               "",
+               "GMT",
             };
         final String[] ETC_UTC = new String[] {
                "\u0938\u092e\u0928\u094d\u0935\u093f\u0924\u0903 \u0935\u0948\u0936\u094d\u0935\u093f\u0915 \u0938\u092e\u092f:",
@@ -84,67 +84,67 @@ public class TimeZoneNames_sa extends TimeZoneNamesBundle {
             };
         final String[] Atlantic = new String[] {
                "\u0905\u091f\u0932\u093e\u0923\u094d\u091f\u093f\u0915 \u0906\u0926\u0930\u094d\u0936 \u0938\u092e\u092f\u0903",
-               "",
+               "AST",
                "\u0905\u091f\u0932\u093e\u0923\u094d\u091f\u093f\u0915 \u0905\u092f\u093e\u092e \u0938\u092e\u092f\u0903",
-               "",
+               "ADT",
                "\u0905\u091f\u0932\u093e\u0923\u094d\u091f\u093f\u0915 \u0938\u092e\u092f\u0903",
-               "",
+               "AT",
             };
         final String[] Europe_Central = new String[] {
                "\u092e\u0927\u094d\u092f \u092f\u0942\u0930\u094b\u092a\u0940\u092f \u0906\u0926\u0930\u094d\u0936 \u0938\u092e\u092f\u0903",
-               "",
+               "CET",
                "\u092e\u0927\u094d\u092f \u092f\u0942\u0930\u094b\u092a\u0940\u092f \u0917\u094d\u0930\u0940\u0937\u094d\u092e \u0938\u092e\u092f\u0903",
-               "",
+               "CEST",
                "\u092e\u0927\u094d\u092f \u092f\u0942\u0930\u094b\u092a\u0940\u092f \u0938\u092e\u092f\u0903",
-               "",
+               "CET",
             };
         final String[] Europe_Eastern = new String[] {
                "\u092a\u094c\u0930\u094d\u0935 \u092f\u0942\u0930\u094b\u092a\u0940\u092f \u0906\u0926\u0930\u094d\u0936 \u0938\u092e\u092f\u0903",
-               "",
+               "EET",
                "\u092a\u094c\u0930\u094d\u0935 \u092f\u0942\u0930\u094b\u092a\u0940\u092f \u0917\u094d\u0930\u0940\u0937\u094d\u092e \u0938\u092e\u092f\u0903",
-               "",
+               "EEST",
                "\u092a\u094c\u0930\u094d\u0935 \u092f\u0942\u0930\u094b\u092a\u0940\u092f \u0938\u092e\u092f\u0903",
-               "",
+               "EET",
             };
         final String[] Europe_Western = new String[] {
                "\u092a\u093e\u0936\u094d\u091a\u093e\u0924\u094d\u092f \u092f\u0942\u0930\u094b\u092a\u0940\u092f \u0906\u0926\u0930\u094d\u0936 \u0938\u092e\u092f\u0903",
-               "",
+               "WET",
                "\u092a\u093e\u0936\u094d\u091a\u093e\u0924\u094d\u092f \u092f\u0942\u0930\u094b\u092a\u0940\u092f \u0917\u094d\u0930\u0940\u0937\u094d\u092e \u0938\u092e\u092f\u0903",
-               "",
+               "WEST",
                "\u092a\u093e\u0936\u094d\u091a\u093e\u0924\u094d\u092f \u092f\u0942\u0930\u094b\u092a\u0940\u092f \u0938\u092e\u092f\u0903",
-               "",
+               "WET",
             };
         final String[] America_Central = new String[] {
                "\u0909\u0924\u094d\u0924\u0930 \u0905\u092e\u0947\u0930\u093f\u0915\u093e: \u092e\u0927\u094d\u092f \u0906\u0926\u0930\u094d\u0936 \u0938\u092e\u092f\u0903",
-               "",
+               "CST",
                "\u0909\u0924\u094d\u0924\u0930 \u0905\u092e\u0947\u0930\u093f\u0915\u093e: \u092e\u0927\u094d\u092f \u0905\u092f\u093e\u092e \u0938\u092e\u092f\u0903",
-               "",
+               "CDT",
                "\u0909\u0924\u094d\u0924\u0930 \u0905\u092e\u0947\u0930\u093f\u0915\u093e: \u092e\u0927\u094d\u092f \u0938\u092e\u092f\u0903",
-               "",
+               "CT",
             };
         final String[] America_Eastern = new String[] {
                "\u0909\u0924\u094d\u0924\u0930 \u0905\u092e\u0947\u0930\u093f\u0915\u093e: \u092a\u094c\u0930\u094d\u0935 \u0906\u0926\u0930\u094d\u0936 \u0938\u092e\u092f\u0903",
-               "",
+               "EST",
                "\u0909\u0924\u094d\u0924\u0930 \u0905\u092e\u0947\u0930\u093f\u0915\u093e: \u092a\u094c\u0930\u094d\u0935 \u0905\u092f\u093e\u092e \u0938\u092e\u092f:",
-               "",
+               "EST",
                "\u0909\u0924\u094d\u0924\u0930 \u0905\u092e\u0947\u0930\u093f\u0915\u093e: \u092a\u094c\u0930\u094d\u0935 \u0938\u092e\u092f\u0903",
-               "",
+               "EST",
             };
         final String[] America_Pacific = new String[] {
                "\u0909\u0924\u094d\u0924\u0930 \u0905\u092e\u0947\u0930\u093f\u0915\u093e: \u0938\u0928\u094d\u0927\u093f\u092a\u094d\u0930\u093f\u092f \u0906\u0926\u0930\u094d\u0936 \u0938\u092e\u092f\u0903",
-               "",
+               "PST",
                "\u0909\u0924\u094d\u0924\u0930 \u0905\u092e\u0947\u0930\u093f\u0915\u093e: \u0938\u0928\u094d\u0927\u093f\u092a\u094d\u0930\u093f\u092f \u0905\u092f\u093e\u092e \u0938\u092e\u092f\u0903",
-               "",
+               "PDT",
                "\u0909\u0924\u094d\u0924\u0930 \u0905\u092e\u0947\u0930\u093f\u0915\u093e: \u0938\u0928\u094d\u0927\u093f\u092a\u094d\u0930\u093f\u092f \u0938\u092e\u092f\u0903",
-               "",
+               "PT",
             };
         final String[] America_Mountain = new String[] {
                "\u0909\u0924\u094d\u0924\u0930 \u0905\u092e\u0947\u0930\u093f\u0915\u093e: \u0936\u0948\u0932 \u0906\u0926\u0930\u094d\u0936 \u0938\u092e\u092f\u0903",
-               "",
+               "MST",
                "\u0909\u0924\u094d\u0924\u0930 \u0905\u092e\u0947\u0930\u093f\u0915\u093e: \u0936\u0948\u0932 \u0905\u092f\u093e\u092e \u0938\u092e\u092f\u0903",
-               "",
+               "MST",
                "\u0909\u0924\u094d\u0924\u0930 \u0905\u092e\u0947\u0930\u093f\u0915\u093e: \u0936\u0948\u0932 \u0938\u092e\u092f\u0903",
-               "",
+               "MST",
             };
         final Object[][] data = new Object[][] {
             { "America/Los_Angeles", America_Pacific },
@@ -171,7 +171,6 @@ public class TimeZoneNames_sa extends TimeZoneNamesBundle {
             { "MST7MDT", America_Mountain },
             { "PST8PDT", America_Pacific },
             { "Asia/Gaza", Europe_Eastern },
-            { "Asia/Amman", Europe_Eastern },
             { "Africa/Lome", GMT },
             { "Asia/Beirut", Europe_Eastern },
             { "Asia/Hebron", Europe_Eastern },
@@ -198,7 +197,6 @@ public class TimeZoneNames_sa extends TimeZoneNamesBundle {
             { "America/Aruba", Atlantic },
             { "America/Boise", America_Mountain },
             { "America/Thule", Atlantic },
-            { "Asia/Damascus", Europe_Eastern },
             { "Europe/Athens", Europe_Eastern },
             { "Europe/Berlin", Europe_Central },
             { "Europe/Dublin", GMT },
@@ -221,7 +219,6 @@ public class TimeZoneNames_sa extends TimeZoneNamesBundle {
             { "America/Belize", America_Central },
             { "America/Cancun", America_Eastern },
             { "America/Cayman", America_Eastern },
-            { "America/Dawson", America_Mountain },
             { "America/Inuvik", America_Mountain },
             { "America/Merida", America_Central },
             { "America/Nassau", America_Eastern },
@@ -247,7 +244,7 @@ public class TimeZoneNames_sa extends TimeZoneNamesBundle {
             { "America/Marigot", Atlantic },
             { "America/Moncton", Atlantic },
             { "America/Nipigon", America_Eastern },
-            { "America/Ojinaga", America_Mountain },
+            { "America/Ojinaga", America_Central },
             { "America/Tijuana", America_Pacific },
             { "America/Toronto", America_Eastern },
             { "America/Tortola", Atlantic },
@@ -287,6 +284,7 @@ public class TimeZoneNames_sa extends TimeZoneNamesBundle {
             { "Europe/Podgorica", Europe_Central },
             { "Europe/Stockholm", Europe_Central },
             { "Africa/Nouakchott", GMT },
+            { "America/Chihuahua", America_Central },
             { "America/Glace_Bay", Atlantic },
             { "America/Goose_Bay", Atlantic },
             { "America/Guatemala", America_Central },
@@ -309,7 +307,6 @@ public class TimeZoneNames_sa extends TimeZoneNamesBundle {
             { "America/Martinique", Atlantic },
             { "America/Montserrat", Atlantic },
             { "America/St_Vincent", Atlantic },
-            { "America/Whitehorse", America_Mountain },
             { "Atlantic/Jan_Mayen", Europe_Central },
             { "Atlantic/Reykjavik", GMT },
             { "Atlantic/St_Helena", GMT },
@@ -331,6 +328,7 @@ public class TimeZoneNames_sa extends TimeZoneNamesBundle {
             { "America/Indiana/Knox", America_Central },
             { "America/Rankin_Inlet", America_Central },
             { "America/Cambridge_Bay", America_Mountain },
+            { "America/Ciudad_Juarez", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
             { "America/Indiana/Vevay", America_Eastern },
             { "America/Lower_Princes", Atlantic },
